@@ -1027,11 +1027,11 @@ terminal_window_init (TerminalWindow *window)
   mi = gtk_separator_menu_item_new ();
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
-  mi = append_menuitem (menu, _("Move Tab _Left"), ACCEL_PATH_MOVE_TAB_LEFT,
+  mi = append_menuitem (menu, _("Move Tab to the _Left"), ACCEL_PATH_MOVE_TAB_LEFT,
                         G_CALLBACK (move_left_tab_callback), window);
   window->priv->move_left_tab_menuitem = mi;
   
-  mi = append_menuitem (menu, _("Move Tab _Right"), ACCEL_PATH_MOVE_TAB_RIGHT,
+  mi = append_menuitem (menu, _("Move Tab to the _Right"), ACCEL_PATH_MOVE_TAB_RIGHT,
                         G_CALLBACK (move_right_tab_callback), window);
   window->priv->move_right_tab_menuitem = mi;
 
@@ -1803,6 +1803,10 @@ notebook_tab_detached_callback (GtkWidget       *notebook,
                                 TerminalScreen  *screen,
                                 TerminalWindow  *window)
 {
+  /* Reset the tab menu before detaching the tab, in case the tab changed
+   * position before it was detached (bug #330246). */
+  reset_tab_menuitems (window);
+
   detach_tab (screen, window);
 }
 
@@ -2169,7 +2173,6 @@ terminal_window_set_fullscreen (TerminalWindow *window,
 gboolean
 terminal_window_get_fullscreen (TerminalWindow *window)
 {
-
   return window->priv->fullscreen;
 }
 
@@ -2215,7 +2218,7 @@ new_window (TerminalWindow *window,
                              screen,
                              FALSE, FALSE, FALSE,
                              NULL, NULL, NULL, dir, NULL, 1.0,
-                             NULL, name, -1, NULL);
+                             NULL, name, -1);
 }
 
 static void
@@ -2241,7 +2244,7 @@ new_tab_callback (GtkWidget      *menuitem,
                                  NULL,
                                  FALSE, FALSE, FALSE,
                                  NULL, NULL, NULL, dir, NULL, 1.0,
-                                 NULL, NULL, -1, NULL);
+                                 NULL, NULL, -1);
     }
 }
 
@@ -2255,6 +2258,7 @@ confirm_close_window (TerminalWindow *window)
   int n;
 
   n = gtk_notebook_get_n_pages (GTK_NOTEBOOK (window->priv->notebook));
+
   if (n <= 1)
     return TRUE;
 
@@ -2262,13 +2266,16 @@ confirm_close_window (TerminalWindow *window)
   if (!gconf_client_get_bool (window->priv->conf, CONF_GLOBAL_PREFIX "/confirm_window_close", &error))
     return TRUE;
 
-  msg1 = g_strdup_printf (ngettext ("This window has one tab open. Closing the window will close it.",
-                                    "This window has %d tabs open. Closing the window will also close all its tabs.",
-                                    n),
-                          n);
-  msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s\n", 
-                         _("Close all tabs?"), 
-                         msg1);
+  msg1 = g_strdup_printf (ngettext ("This window has one tab open. Closing "
+				    "the window will close it.",
+				    "This window has %d tabs open. Closing "
+				    "the window will also close all of its "
+				    "tabs.",
+				    n),
+			  n);
+
+  msg = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n"
+			 "%s\n", _("Close all tabs?"), msg1);
 
   dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (window),
                                    GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -2764,7 +2771,7 @@ detach_tab_callback(GtkWidget      *menuitem,
                     TerminalWindow *window)
 {
   GtkNotebook *notebook;
-  gint page_num,last_page;
+  gint page_num;
   GtkWidget *page; 
 
   notebook = GTK_NOTEBOOK (window->priv->notebook);
@@ -2772,9 +2779,6 @@ detach_tab_callback(GtkWidget      *menuitem,
   page = gtk_notebook_get_nth_page (notebook, page_num);
   
   detach_tab (TERMINAL_SCREEN (page), window);
-  
-  update_tab_sensitivity (window);
-  reset_tab_menuitems (window);
 }
 
 static void
@@ -2809,12 +2813,28 @@ about_callback (GtkWidget      *menuitem,
 
   const char *copyright =
     "Copyright \xc2\xa9 2002-2004 Havoc Pennington\n"
-    "Copyright \xc2\xa9 2003-2004 Mariano Su\303\241rez-Alvarez";
+    "Copyright \xc2\xa9 2003-2004 Mariano Su\303\241rez-Alvarez\n"
+    "Copyright \xc2\xa9 2006 Guilherme de S. Pastore";
   const char *authors[] = {
+    "Guilherme de S. Pastore <gpastore@gnome.org> (maintainer)",
     "Havoc Pennington <hp@redhat.com>",
     "Mariano Su\303\241rez-Alvarez <mariano@gnome.org>",
     NULL
   };
+  const gchar *license[] = {
+    "GNOME Terminal is free software; you can redistribute it and/or modify \n"
+    "it under the terms of the GNU General Public License as published by \n"
+    "the Free Software Foundation; either version 2 of the License, or \n"
+    "(at your option) any later version.",
+    "GNOME Terminal is distributed in the hope that it will be useful, \n"
+    "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
+    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
+    "GNU General Public License for more details.",
+    "You should have received a copy of the GNU General Public License \n"
+    "along with Nautilus; if not, write to the Free Software Foundation, Inc., \n"
+    "51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA"
+  };
+  const gchar *license_text;
 
   if (about)
     {
@@ -2825,7 +2845,13 @@ about_callback (GtkWidget      *menuitem,
 				     
   about = gtk_about_dialog_new ();
 
+  license_text = g_strconcat (license[0], "\n\n", license[1], "\n\n",
+			      license[2], "\n\n", NULL);
+
+  gtk_about_dialog_set_license (GTK_ABOUT_DIALOG (about), license_text);
+
   gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (about), _("GNOME Terminal"));
+  gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG(about), _("A terminal emulator for the GNOME desktop"));
   gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (about), VERSION);
   gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about), copyright);
   gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (about), authors);
